#[non_exhaustive]pub enum EventMapping {
Ignore,
Breadcrumb(Breadcrumb),
Event(Event<'static>),
Log(Log),
Combined(CombinedEventMapping),
}Expand description
The type of data Sentry should ingest for an Event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ignore
Ignore the Event
Breadcrumb(Breadcrumb)
Adds the Breadcrumb to the Sentry scope.
Event(Event<'static>)
Captures the sentry_core::protocol::Event to Sentry.
Log(Log)
Captures the sentry_core::protocol::Log to Sentry.
Combined(CombinedEventMapping)
Captures multiple items to Sentry.
Nesting multiple EventMapping::Combined inside each other will cause the inner mappings to be ignored.